@@ -348,13 +348,17 @@ def build_node_and_resolver(
                 property_name = f"{prop.name}_"
                 property_str = f'{property_name}: T.Union[{type_str}, Unset] = Field(default_factory=Unset, alias="{prop.name}")'
             property_strs.append(property_str)
+            val_str = "val"
+            if "Set[" in type_str:
+                val_str = f"val if type(val) != list else set(val)"
             computed_property_getter_strs.append(
                 f"""
 @property
 def {prop.name}(self) -> {type_str}:
     if is_unset(self.{property_name}):
         if "{prop.name}" in self.extra:
-            self.{property_name} = self.extra["{prop.name}"]
+            val = self.extra["{prop.name}"]
+            self.{property_name} = {val_str}
         else:
             raise {exception_name}("{prop.name} is unset")
     return self.{property_name}
